# is-furry-py
Returns True if a string contains a variation of "OwO"


## Setup
- Install the module
    > pip install is-furry-py
- Use it in your code

```py
from is_furry import evaluate
```

## Options
Options are not currently supported in is-furry-py.

## License
The project is licensed under [MIT](https://github.com/wait-what/is-furry/-/blob/master/LICENSE)

## Contributing
If you would like to contribute to this package, please read the [contributing guide](https://github.com/wait-what/is-furry/blob/master/CONTRIBUTING.md).

Thanks to [jakobkg](https://github.com/jakobkg) for improving the typings!

## Support
Original Creator: `Wait What#497(five)`
Python Translation: `Bunniico#371(6)`
